Package: RcppRedis
Type: Package
Title: 'Rcpp' Bindings for 'Redis' using the 'hiredis' Library
Version: 0.2.6
Date: 2025-06-24
Authors@R: c(person("Dirk", "Eddelbuettel", role = c("aut", "cre"), email = "edd@debian.org",
                    comment = c(ORCID = "0000-0001-6419-907X")),
             person("Bryan", "Lewis", role = "aut", comment = "pub/sub code from 'rredis'"))
Description: Connection to the 'Redis' (or 'Valkey') key/value store
 using the C-language client library 'hiredis' (included as a fallback)
 with 'MsgPack' encoding provided via 'RcppMsgPack' headers. It now
 also includes the pub/sub functions from the 'rredis' package.
SystemRequirements: An available hiredis library (eg via package
        libhiredis-dev on Debian/Ubuntu, hiredis-devel on
        Fedora/RedHat, or directly from source from
        <https://github.com/redis/hiredis>) can be used but version
        1.0.2 is also included and built on demand if needed. The
        optional 'rredis' package can be installed from the 'ghrr'
        'drat' repo for additional illustrations and tests.
URL: https://github.com/eddelbuettel/rcppredis,
        https://dirk.eddelbuettel.com/code/rcpp.redis.html
BugReports: https://github.com/eddelbuettel/rcppredis/issues
License: GPL (>= 2)
Imports: methods, Rcpp (>= 0.11.0), RApiSerialize (>= 0.1.4)
LinkingTo: Rcpp, RApiSerialize
Suggests: RcppMsgPack, tinytest
NeedsCompilation: yes
Packaged: 2025-06-24 14:09:03 UTC; edd
Author: Dirk Eddelbuettel [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6419-907X>),
  Bryan Lewis [aut] (pub/sub code from 'rredis')
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2025-06-24 14:30:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 21:39:08 UTC; unix
Archs: RcppRedis.so.dSYM
