useDynLib(RcppRedis, .registration=TRUE)	# shared library from this package
import(methods,Rcpp,RApiSerialize)	        # packages we require
exportPattern("^[[:alpha:]]+")          	# export all identifiers starting with letters
